@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: cheapskate
 version: 0.1.0.4
-id: cheapskate-0.1.0.4-e7084c4882f04909c69473a4ceb8b891
-key: cheap_4gBbzsQgbCzJLY3OiCuVWd
+id: cheapskate-0.1.0.4-c2e9c000038a7a74d6b3323df2bd8de6
+key: cheap_1yivIgsZUUnAmg2ZWLLmDt
 license: BSD3
 copyright: (C) 2012-2013 John MacFarlane
 maintainer: jgm@berkeley.edu
@@ -31,17 +31,17 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/cheapskate-0.1.0.4
 library-dirs: /usr/lib/ghc-7.10.3/site-local/cheapskate-0.1.0.4
 data-dir: /usr/share/arm-linux-ghc-7.10.3/cheapskate-0.1.0.4
-hs-libraries: HScheapskate-0.1.0.4-4gBbzsQgbCzJLY3OiCuVWd
+hs-libraries: HScheapskate-0.1.0.4-1yivIgsZUUnAmg2ZWLLmDt
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
+    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
-    uniplate-1.6.12-5a2a0a6de90df137bffce599d35d6149
-    xss-sanitize-0.3.5.6-b3b679ace14b1ead6abf3b67e5cfe55e
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
+    uniplate-1.6.12-474087ddfa30ffe8f83d021d3c4c23e6
+    xss-sanitize-0.3.5.6-f78b5b03aa1efe6d65b9961065a15c78
 haddock-interfaces: /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
 haddock-html: /usr/share/doc/haskell-cheapskate/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
